/*
--------------------------------------------------------------------------------
*** T-SQL Chart
--------------------------------------------------------------------------------
Description:  This script creates stored procedures and functions that turn a 
              given SELECT statement into a chart or a drawing representing 
              selected data. Supports chart types LINE, COLUMN, BAR, PIE, and 
              AREA, and a special type PAINT for free-style drawings.
--------------------------------------------------------------------------------
Authors:      Andrew Zanevsky, Katrin Zanevsky, and Anthony Zanevsky
Email:        zanevsky@azdatabases.com
Version Date: 2011-12-24
--------------------------------------------------------------------------------
Objects created by this script:
 ----- Basic objects to produce charts and free-style drawings:
 - Chart         The main stored procedure to generate charts and drawings from 
                 a given SELECT query.
 - WKT_Letter    User-defined function to create a WKT string to draw a given 
                 ASCII character.
 - WKT_String    User-defined function to create a WKT string to draw a given 
                 ASCII string.
 - Chart_Colors  Stored procedure to draw a chart of available colors and their 
                 sequence numbers. It is useful to pick unwanted colors for the 
                 @Skip_Colors parameter of the Chart procedure.
 ----- Stored procedures that use objects listed above:
 - Chart_Free_Disk_Space   - Stored procedure to display a pie chart of 
                             currently available free disk space by drive letter.
 - Chart_DB_Size           - Stored procedure to display a column, pie, or bar 
                             chart depicting relative database sizes.
 - Chart_Job_Duration      - Stored procedure to display a line chart of 
                             execution history of a given job.
 - Chart_Job_Step_Duration - Stored procedure to display an area or column 
                             chart of execution history of a given job by step 
                             (shown as separate data series of different colors).
 - Chart_All_Jobs_History  - Stored procedure to display a floating bar chart 
                             depicting execution history of all scheduled jobs 
                             that took longer than a given duration and that 
                             were started within a given time range.
 - Chart_Art               - Stored procedure to create computer-generated art -
                             either generate a random drawing or reproduce a 
                             specific drawing from a given integer seed.
--------------------------------------------------------------------------------
Usage instructions:
   All objects have header comments explaining their purpose and inline comments
   after each parameter explaining its usage and defaults.
--------------------------------------------------------------------------------
Installation instructions:
   Execute this script from a query window in a database where you want to 
   install them. It is sufficient to install these objects in just one database 
   on a particular SQL Server, as they may be used to produce charts based on 
   data selected from any other database on the same server or linked servers, 
   provided that the user executing the procedure has read permissions on 
   objects involved in the given SELECT.
   Note that if objects with the same names already exist in the database, then 
   this script will attempt to alter them and replace with versions found in 
   this script.
--------------------------------------------------------------------------------
*/

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
IF OBJECT_ID( 'dbo.WKT_Letter' ) IS NULL EXEC( 'CREATE FUNCTION dbo.WKT_Letter() RETURNS varchar(max) AS BEGIN RETURN( '''' ) END' )
GO
ALTER FUNCTION dbo.WKT_Letter( 
----------------------------------------------------------------
-- Description: Return a WKT string to produce an image of a 
--              given ASCII character.
-- Revision History:
-- ---Date--- ---Programmer---- ---Description------------------
-- 2011-12-24 Andrew Zanevsky,	Original version
--            Anthony Zanevsky
----------------------------------------------------------------
	@l  char(1), -- an ASCII character to convert to WKT
	@xs float,   -- horizontal scale (defines the width of the character on the grid)
	@xo float,   -- horizontal origin (X coordinate of the lower left corner of the character on the grid)
	@ys float,   -- vertial scale (defines the height of the character on the grid)
	@yo float    -- vertial origin (Y coordinate of the lower left corner of the character on the grid)
)
RETURNS VARCHAR(max)
AS
BEGIN;
RETURN( CASE ASCII( @l )
			/*A*/ WHEN  65 THEN '(' + CAST( 0.247619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.552381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.460952 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.407619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.338762 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.140952 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.338762 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.08 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0190476 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.247619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.270476 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.674 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.384762 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.407333 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.16381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.407333 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.270476 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.674 * @ys + @yo AS varchar(30) ) + ')'
			/*B*/ WHEN  66 THEN '(' + CAST( 0.0761905 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.32 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.388571 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.75019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.426667 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.727333 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.457143 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.696857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.472381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658762 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.472381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.613048 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.457143 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.574952 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.426667 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.536857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.380952 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.506381 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.342857 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.491143 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.388571 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.475905 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411429 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.468286 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.434286 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.453048 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.472381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.422571 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.487619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.384476 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.495238 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.361619 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.495238 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.315905 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.48 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.27019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.449524 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232095 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.209238 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.32 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0761905 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0761905 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.167619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.696857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.304762 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.696857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.335238 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.689238 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.365714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.666381 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.373333 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.643524 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.373333 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.59019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358095 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.559714 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.327619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.536857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.274286 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.521619 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.521619 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.696857 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.167619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.460667 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.274286 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.460667 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.32 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358095 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.422571 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.39619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.376857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.39619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.308286 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.373333 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.27781 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.327619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.262571 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.262571 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.460667 * @ys + @yo AS varchar(30) ) + ')'
			/*C*/ WHEN  67 THEN '(' + CAST( 0.514286 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.75019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.415238 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.780667 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.308571 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.780667 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.224762 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.75781 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.15619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.719714 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.110476 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.674 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.072381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.605429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0495238 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.521619 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0495238 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0647619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.376857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0952381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.308286 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.148571 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.247333 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.201905 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.216857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.24 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.308571 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.178762 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377143 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.178762 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.186381 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.521905 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.209238 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.521905 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.27019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.499048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.262571 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.438095 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.239714 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.32381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.239714 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.270476 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.254952 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.209524 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300667 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.15619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.369238 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.140952 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.422571 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.140952 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.536857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.16381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.59781 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.201905 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.651143 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.255238 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.696857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300952 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.719714 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.407619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.719714 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.514286 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.681619 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.514286 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.75019 * @ys + @yo AS varchar(30) ) + ')'
			/*D*/ WHEN  68 THEN '(' + CAST( 0.0533333 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.274286 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.335238 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.75781 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.39619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.734952 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.441905 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.704476 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.48 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658762 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.502857 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.605429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.518095 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.536857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.518095 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.453048 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.510476 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.392095 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.487619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.331143 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.457143 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.285429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.419048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.247333 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.365714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.216857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.32 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.201619 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.259048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0533333 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0533333 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.144762 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.696857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266667 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.696857 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.327619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.681619 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.380952 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.643524 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.605429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.419048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.544476 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.419048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.414952 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40381 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.380952 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.323524 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.335238 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.285429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.297143 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.27019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251429 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.262571 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.144762 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.262571 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.144762 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.696857 * @ys + @yo AS varchar(30) ) + ')'
			/*E*/ WHEN  69 THEN '(' + CAST( 0.0838095 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464762 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464762 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.704476 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.704476 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.521619 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.419048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.521619 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.419048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.460667 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.460667 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.254952 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.487619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.254952 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.487619 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0838095 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0838095 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*F*/ WHEN  70 THEN '(' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*G*/ WHEN  71 THEN '(' + CAST( 0.508475 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.717002 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.062954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.062954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.358649 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.140436 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.407075 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.140436 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.508475 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.508475 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ')'
			/*H*/ WHEN  72 THEN '(' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*I*/ WHEN  73 THEN '(' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*J*/ WHEN  74 THEN '(' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*K*/ WHEN  75 THEN '(' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.513317 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ')'
			/*L*/ WHEN  76 THEN '(' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*M*/ WHEN  77 THEN '(' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.407075 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.101695 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.101695 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*N*/ WHEN  78 THEN '(' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*O*/ WHEN  79 THEN '(' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.736373 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.736373 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ')'
			/*P*/ WHEN  80 THEN '(' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.736373 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.503927 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.503927 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300242 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ')'
			/*Q*/ WHEN  81 THEN '(' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.736373 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.460048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.508475 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.508475 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.460048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.155259 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.547215 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.116518 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0487215 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0874625 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.126203 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.062954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.736373 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ')'
			/*R*/ WHEN  82 THEN '(' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746058 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.513317 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ')'
			/*S*/ WHEN  83 THEN '(' + CAST( 0.437788 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.728562 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.437788 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.664046 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.419355 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.673263 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.391705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.682479 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.336406 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.691696 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.235023 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.691696 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198157 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.682479 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.170507 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.664046 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.16129 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.645613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.16129 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.59953 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.57188 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.207373 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.553447 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271889 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.525797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.373272 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.488931 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.428571 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.461281 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.456221 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.433631 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474654 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.405982 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.483871 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378332 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.483871 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.313816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.465438 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.267733 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.428571 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.230866 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382488 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203217 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.317972 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184783 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.225806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184783 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.170507 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0875576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.212433 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0875576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.286166 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.142857 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.267733 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.21659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.2493 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.317972 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.2493 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.354839 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.258516 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382488 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.276949 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.410138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.304599 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.410138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.359899 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.391705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387548 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.354839 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.405982 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.262673 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.442848 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.18894 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.470498 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.142857 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.498147 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.105991 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.535014 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0875576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.57188 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0875576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.636396 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.105991 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.682479 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.152074 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.728562 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.18894 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746995 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.235023 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.756212 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.327189 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.756212 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382488 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746995 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.419355 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.737779 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.437788 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.728562 * @ys + @yo AS varchar(30) ) + ')'
			/*T*/ WHEN  84 THEN '(' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.552058 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.552058 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*U*/ WHEN  85 THEN '(' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.348964 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.460048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.140436 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*V*/ WHEN  86 THEN '(' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.552058 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*W*/ WHEN  87 THEN '(' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.552058 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*X*/ WHEN  88 THEN '(' + CAST( 0.0387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.542373 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.552058 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*Y*/ WHEN  89 THEN '(' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.116223 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.552058 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*Z*/ WHEN  90 THEN '(' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.140436 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*0*/ WHEN  48 THEN '(' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.82354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.717002 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.513317 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.513317 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.348964 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.717002 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.116223 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862281 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.407075 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.358649 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.736373 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ')'
			/*1*/ WHEN  49 THEN '(' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.508475 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.508475 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.062954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.062954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.062954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.736373 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.062954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ')'
			/*2*/ WHEN  50 THEN '(' + CAST( 0.116223 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862281 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862281 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.465186 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.804169 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.804169 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.116223 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.116223 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ')'
			/*3*/ WHEN  51 THEN '(' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862281 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862281 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.804169 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.465186 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469734 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.407075 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469734 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.101695 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.101695 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.503927 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746058 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.804169 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ')'
			/*4*/ WHEN  52 THEN '(' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.508475 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.508475 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.062954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.062954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.736373 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.736373 * @ys + @yo AS varchar(30) ) + ')'
			/*5*/ WHEN  53 THEN '(' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.2954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ')'
			/*6*/ WHEN  54 THEN '(' + CAST( 0.460048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.460048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.804169 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.717002 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.503927 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469734 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.101695 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.833225 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862281 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.2954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862281 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.460048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.348964 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.358649 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ')'
			/*7*/ WHEN  55 THEN '(' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.465186 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ')'
			/*8*/ WHEN  56 THEN '(' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862281 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.465186 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.503927 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.116223 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746058 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.833225 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862281 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746058 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300242 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746058 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.407075 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ')'
			/*9*/ WHEN  57 THEN '(' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.460048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.465186 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ')'
			/*`*/ WHEN  96 THEN '(' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.988189 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.2954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.988189 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.988189 * @ys + @yo AS varchar(30) ) + ')'
			/*~*/ WHEN 126 THEN '(' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.407075 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.407075 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.513317 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.348964 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.348964 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.116223 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ')'
			/*!*/ WHEN  33 THEN '(' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ')'
			/*@*/ WHEN  64 THEN '(' + CAST( 0.547215 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.547215 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.717002 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.736373 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.804169 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.82354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.82354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.804169 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.348964 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.101695 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.833225 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862281 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.82354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469734 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.547215 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.2954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ')'
			/*#*/ WHEN  35 THEN '(' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.542373 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ')'
			/*$*/ WHEN  36 THEN '(' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.910707 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.910707 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.82354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.503927 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.135889 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.135889 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.82354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.910707 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ')'
			/*%*/ WHEN  37 THEN '(' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.561743 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.00968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.833225 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.804169 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746058 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.00968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.00968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746058 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.833225 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.736373 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746058 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.542373 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.561743 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.561743 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.542373 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300242 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300242 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.465186 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ')'
			/*^*/ WHEN  94 THEN '(' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.116223 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ')'
			/*&*/ WHEN  38 THEN '(' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.556901 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.556901 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.547215 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.527845 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469734 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.556901 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.17463 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.062954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.82354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.871966 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.82354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.717002 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.407075 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.460048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.2954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.348964 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.140436 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.101695 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.358649 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.101695 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.503927 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ')'
			/***/ WHEN  42 THEN '(' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.717002 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.717002 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.116223 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*(*/ WHEN  40 THEN '(' + CAST( 0.469003 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469003 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.927154 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.415094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.916372 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.350404 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.884027 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.264151 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.797774 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.221024 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.71152 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188679 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.603704 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188679 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.441978 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.221024 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.334162 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.264151 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.247908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.328841 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.172437 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.404313 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.12931 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469003 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.107747 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469003 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.404313 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0646199 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.350404 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0861833 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.307278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.107747 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242588 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.161655 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.177898 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.237127 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.134771 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.32338 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.102426 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.441978 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.102426 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.58214 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.123989 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.700739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167116 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.797774 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.894809 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.948717 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.393531 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.981062 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469003 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ')'
			/*)*/ WHEN  41 THEN '(' + CAST( 0.102426 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.102426 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.927154 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.156334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.916372 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.221024 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.884027 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.307278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.797774 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.350404 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.71152 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382749 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.603704 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382749 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.441978 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.350404 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.334162 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.307278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.247908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242588 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.172437 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167116 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.12931 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.102426 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.107747 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.102426 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167116 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0646199 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.221024 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0861833 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.264151 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.107747 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.328841 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.161655 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.393531 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.237127 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.436658 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.32338 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469003 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.441978 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469003 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.58214 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.447439 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.700739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.404313 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.797774 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.894809 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.948717 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.177898 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.981062 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.102426 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ')'
			/*-*/ WHEN  45 THEN '(' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ')'
			/*_*/ WHEN  95 THEN '(' + CAST( 0.00968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.561743 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.561743 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.126203 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.00968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.126203 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.00968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ')'
			/*=*/ WHEN  61 THEN '(' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ')'
			/*+*/ WHEN  43 THEN '(' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ')'
			/*[*/ WHEN  91 THEN '(' + CAST( 0.134771 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.436658 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.436658 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.927154 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.210243 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.927154 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.210243 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.118528 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.436658 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.118528 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.436658 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.134771 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.134771 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ')'
			/*{*/ WHEN 123 THEN '(' + CAST( 0.479784 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479784 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.927154 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.393531 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.927154 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.361186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.916372 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.894809 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.296496 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862464 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.296496 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.819337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.307278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.77621 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.71152 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.625267 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.296496 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571358 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.539013 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.231806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.528232 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.51745 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.495887 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.431197 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.334162 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.296496 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.25869 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.296496 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.183218 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.150873 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.371968 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.118528 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479784 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.118528 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479784 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382749 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0646199 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.264151 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.096965 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242588 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.118528 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.221024 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.161655 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.221024 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.247908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.231806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.312598 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242588 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.355725 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242588 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.409633 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.231806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.441978 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.210243 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474323 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167116 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.495887 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0916442 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.495887 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0916442 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.560577 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.167116 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.560577 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.221024 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.58214 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.231806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.614485 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242588 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.64683 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242588 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.700739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.231806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.733084 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.221024 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.797774 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.221024 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.884027 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242588 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.937935 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.97028 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.361186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479784 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ')'
			/*]*/ WHEN  93 THEN '(' + CAST( 0.436658 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.134771 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.134771 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.927154 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.361186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.927154 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.361186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.118528 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.134771 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.118528 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.134771 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.436658 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.436658 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ')'
			/*}*/ WHEN 125 THEN '(' + CAST( 0.0916442 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0916442 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.927154 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.177898 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.927154 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.210243 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.916372 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.894809 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.274933 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.862464 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.274933 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.819337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.264151 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.77621 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.71152 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.625267 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.274933 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571358 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.539013 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.339623 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.528232 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.51745 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.495887 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.431197 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.334162 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.274933 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.25869 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.274933 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.183218 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.150873 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.199461 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.118528 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0916442 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.118528 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0916442 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188679 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0646199 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.307278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.096965 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.328841 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.118528 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.350404 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.161655 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.350404 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.247908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.339623 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.312598 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.328841 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.355725 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.328841 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.409633 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.339623 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.441978 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.361186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474323 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.404313 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.495887 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479784 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.495887 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479784 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.560577 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.404313 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.560577 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.350404 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.58214 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.339623 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.614485 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.328841 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.64683 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.328841 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.700739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.339623 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.733084 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.350404 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.797774 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.350404 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.884027 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.328841 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.937935 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.97028 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.210243 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0916442 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ')'
			/*\*/ WHEN  92 THEN '(' + CAST( 0.0215633 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0862534 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.549865 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.485175 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0215633 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ')'
			/*|*/ WHEN 124 THEN '(' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.318059 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.253369 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ')'
			/*;*/ WHEN  59 THEN '(' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.126203 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300242 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0874625 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.068092 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0584068 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0584068 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0971477 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.106833 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.126203 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.164944 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ')'
			/*:*/ WHEN  58 THEN '(' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ')'
			/*"*/ WHEN  34 THEN '(' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.140436 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.140436 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.717002 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746058 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775114 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.726688 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.697632 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.717002 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746058 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ')'
			/*,*/ WHEN  44 THEN '(' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.126203 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300242 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0874625 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.068092 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0584068 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0584068 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0971477 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.106833 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.126203 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.164944 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ')'
			/*<*/ WHEN  60 THEN '(' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ')'
			/*.*/ WHEN  46 THEN '(' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ')'
			/*>*/ WHEN  62 THEN '(' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ')'
			/*?*/ WHEN  63 THEN '(' + CAST( 0.0701754 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.745378 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0701754 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.865679 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0802005 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.875704 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130326 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.885729 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.200501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.895754 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.330827 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.895754 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411028 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.875704 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.461153 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.845629 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.491228 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.805529 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.501253 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775454 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.501253 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.725328 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.491228 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.695253 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.461153 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.645128 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401003 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.595003 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.320802 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.524827 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300752 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494752 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280702 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.454652 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280702 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.394501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.200501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.394501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.200501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.434602 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.210526 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474702 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.230576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.524827 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.260652 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.554902 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.340852 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.625078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.390977 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.675203 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411028 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.715303 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411028 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.745378 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401003 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.775454 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.370927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.805529 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.330827 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.825579 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300752 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.835604 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.200501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.835604 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.160401 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.825579 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130326 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.815554 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130326 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.745378 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0701754 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.745378 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.190476 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.284226 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290727 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.284226 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290727 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.190476 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.190476 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.284226 * @ys + @yo AS varchar(30) ) + ')'
			/*/ */WHEN  47 THEN '(' + CAST( 0.549865 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.485175 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0215633 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0862534 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0538383 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.549865 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.991844 * @ys + @yo AS varchar(30) ) + ')'
			/*'*/ WHEN  39 THEN '(' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.910707 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.910707 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300242 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.707317 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.746058 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.784799 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.910707 * @ys + @yo AS varchar(30) ) + ')'
			/*a*/ WHEN  97 THEN '(' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.513317 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.348964 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.465186 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.348964 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ')'
			/*b*/ WHEN  98 THEN '(' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469734 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.503927 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.348964 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469734 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ')'
			/*c*/ WHEN  99 THEN '(' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.135593 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ')'
			/*d*/ WHEN 100 THEN '(' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.465186 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.348964 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300242 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ')'
			/*e*/ WHEN 101 THEN '(' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.101695 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469734 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.41676 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ')'
			/*f*/ WHEN 102 THEN '(' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.891337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.833225 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300242 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.833225 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.755743 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.813855 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.852596 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.881651 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.910707 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.910707 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.891337 * @ys + @yo AS varchar(30) ) + ')'
			/*g*/ WHEN 103 THEN '(' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.145574 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469734 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0971477 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0584068 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0293511 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.00998063 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0002954 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0002954 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.00998063 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0196659 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0874625 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.068092 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0584068 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0584068 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0777772 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.106833 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.155259 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.358649 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.2954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.474872 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ')'
			/*h*/ WHEN 104 THEN '(' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.460048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.2954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ')'
			/*i*/ WHEN 105 THEN '(' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*j*/ WHEN 106 THEN '(' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.794484 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.164944 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.430993 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.116518 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.068092 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0293511 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.2954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0002954 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0002954 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.00998063 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0196659 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0874625 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.068092 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0584068 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0584068 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0777772 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0971477 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.145574 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*k*/ WHEN 107 THEN '(' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*l*/ WHEN 108 THEN '(' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.84291 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.901022 * @ys + @yo AS varchar(30) ) + ')'
			/*m*/ WHEN 109 THEN '(' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.2954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.460048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.508475 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.639521 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.51816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*n*/ WHEN 110 THEN '(' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.469734 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.571724 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.2954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*o*/ WHEN 111 THEN '(' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.649206 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.532983 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.513317 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.513317 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.223056 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.174334 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.116223 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0581114 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0774818 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.116223 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.552354 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ')'
			/*p*/ WHEN 112 THEN '(' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.450363 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.503927 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.440678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.324455 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.208232 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.00998063 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.00998063 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.411622 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.343826 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ')'
			/*q*/ WHEN 113 THEN '(' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.382567 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.285714 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.217918 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.121065 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.503927 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.319908 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.363196 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.00998063 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.00998063 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')' + ',' + '(' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.591094 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.305085 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.237288 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.179177 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.159806 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.378019 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.372881 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.421308 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ')'
			/*r*/ WHEN 114 THEN '(' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.464891 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*s*/ WHEN 115 THEN '(' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.60078 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.338983 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.261501 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.542668 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.213075 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.513613 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.445816 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.407075 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.358649 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.474576 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300242 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0968523 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.271482 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.397094 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.339278 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.368039 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.368334 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.309927 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.39739 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.426446 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.455501 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.484557 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.523298 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.581409 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.154964 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.658891 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.348668 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.687947 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.40678 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.445521 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ')'
			/*t*/ WHEN 116 THEN '(' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.271186 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.300242 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.358354 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.22276 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.20339 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.610465 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0677966 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.668576 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			/*u*/ WHEN 117 THEN '(' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.329593 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.276029 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.261797 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.33414 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.358649 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.479419 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.401937 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.353511 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.232741 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.31477 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.256659 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.198547 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.184315 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.203685 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.11138 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.242426 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.300538 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0920097 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*v*/ WHEN 118 THEN '(' + CAST( 0.0387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.532688 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.319613 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.242131 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0387409 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*w*/ WHEN 119 THEN '(' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0871671 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.164649 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.290852 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.251816 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.629835 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.416465 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.281167 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.493947 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.552058 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.455206 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.377724 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.562039 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.184019 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.106538 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0193705 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*x*/ WHEN 120 THEN '(' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.145278 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.290557 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.494242 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.503632 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.329298 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.523002 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.42615 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.280872 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.387705 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.125908 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.232446 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.436131 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0484262 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*y*/ WHEN 121 THEN '(' + CAST( 0.0435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.130751 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.2954 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.310223 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.460048 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.527845 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.266344 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0874625 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.227603 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0390363 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0196659 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.140436 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.00998063 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.00998063 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.068092 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.150121 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.068092 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.188862 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.0971477 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.246973 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.21337 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0435835 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*z*/ WHEN 122 THEN '(' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.489104 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.169492 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.498789 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0726392 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.252111 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.392252 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.62015 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.0823245 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.678262 * @ys + @yo AS varchar(30) ) + ')'
			/*#*/ WHEN   8 THEN '(' + CAST( 0 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0.571429 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.194 * @ys + @yo AS varchar(30) ) + ',' + ' ' + CAST( 0.571429 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ',' + CAST( 0 * @xs + @xo AS varchar(30) ) + ' ' + CAST( 0.765429 * @ys + @yo AS varchar(30) ) + ')'
			ELSE NULL
		END );
END;
GO

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
IF OBJECT_ID( 'dbo.WKT_String' ) IS NULL EXEC( 'CREATE FUNCTION dbo.WKT_String() RETURNS VARCHAR(max) AS BEGIN RETURN( '''' ) END' )
GO
ALTER FUNCTION dbo.WKT_String (
----------------------------------------------------------------
-- Description: Return a WKT string to produce an image of a 
--              given text string.
-- Revision History:
-- ---Date--- ---Programmer---- ---Description------------------
-- 2011-12-24 Andrew Zanevsky	Original version
----------------------------------------------------------------
	@text varchar(100), -- a string of ASCII characters to convert to WKT
	@xs   float,        -- horizontal scale (defines the width of a single character on the grid)
	@xo   float,        -- horizontal origin (X coordinate of the lower left corner of the string on the grid)
	@ys   float,        -- vertial scale (defines the height of a single character on the grid)
	@yo   float         -- vertial origin (Y coordinate of the lower left corner of the string on the grid)
)
RETURNS VARCHAR(max)
AS
BEGIN;
	DECLARE @n int, @len int, @g varchar(max), @l varchar(max);
	SET @len = LEN( @text );
	SET @n = 0;
	WHILE @n < @len BEGIN;
		SET @n = @n + 1;
		SET @l = dbo.WKT_Letter( SUBSTRING( @text, @n, 1 ), @xs, @xo, @ys, @yo );
		IF @l IS NOT NULL SET @g = COALESCE( @g + ',', '' ) + @l;
		SET @xo = @xo + .571 * @xs;
	END;
	RETURN( @g );
END;
GO

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
IF OBJECT_ID( 'dbo.Chart' ) IS NULL EXEC( 'CREATE PROC dbo.Chart AS SELECT x=0' )
GO
ALTER PROC dbo.Chart
----------------------------------------------------------------
-- Description: Display results of a SELECT statement as a chart
-- Revision History:
-- ---Date--- ---Programmer---- ---Description------------------
-- 2011-12-24 Andrew Zanevsky	Original public version.
----------------------------------------------------------------
	@SQL         varchar(max),           -- A query selecting: [for PIE charts] SeriesName,Y or [for all other chart types] SeriesName,X,Y 
                                             -- For example: 'SELECT ProductName, FiscalYear, SalesAmount FROM Sales ORDER BY ProductName, FiscalYear'
	@Chart_Type  varchar(20)   = 'LINE', -- LINE, AREA, COLUMN, BAR, PIE, or PAINT (any other value is treated as LINE)
	@Title       varchar(100)  = '',     -- Chart title (NULL or '' = no title)
	@Y_Base      float         = NULL,   -- Optional parameter for AREA and COLUMN charts: base value for the Y axis. NULL = the lesser of min(Y) or 0.
	@Y_Scale     float         = NULL,   -- 1 grid unit on the Y axis is worth @Y_Scale units of data in the Y column of the given SELECT query:
                                             -- NULL = let the procedure automatically scale the image for optimal presentation on a typical screen; 
                                             -- 1 = no scaling; >1 = reduce the height of the image; (0...1) = extend the height of the image; 0 = causes an error;
                                             -- <0 - flip the image upside down and scale it the same way as ABS(@Y_Scale) would scale it.
	@Scaling25   bit           = 1,      -- Only used if automatic scaling is allowed (@Y_Scale=NULL):
                                             -- 0 = only scale to powers of 10; 1 = scale to 10^n, 2*10^n, or 5*10^n
	@Col_Width   float         = 0.6,    -- For COLUMN charts, defines the width of each column as a fraction of 1 
                                             -- (e.g. 1 = no gaps between columns; 0.6 = each column fills 60% of the width leaving 40% gaps between columns)
	@All_Other   float         = 0.02,   -- For PIE charts, all values smaller than this fraction of the total are grouped into one "All Other" pie slice.
	@Legend      bit           = NULL,   -- Print legend (series names provided by the given SELECT query)? 1=yes/0=no. Default: 0 for PAINT charts, 1 for other types.
	@Legend_Over bit           = 0,      -- For BAR charts, defines if the procedure should print series names inside bars instead of on the right side. 1=yes/0=no
	@Y_Grid      bit           = NULL,   -- Print Y grid values on the Y axis? 1=yes/0=no. Default: 0 for PAINT charts, 1 for other types.
                                             -- Note that automatically printed grid values on the X axis correspond to actual X values provided by the given 
                                             -- SELECT query, but grid values on the Y axis only match actual Y values provided by the query when the @Y_Scale=1 
                                             -- or when @Y_Scale=NULL and auto-scaling chooses the scale of 1. Therefore, it is recommended to use @Y_Grid=1,
                                             -- because it makes the procedure print real Y grid values.
	@Skip_Colors varchar(1000) = NULL,   -- Comma-separated list of "ugly" color numbers to skip (exec dbo.Chart_Colors to get the color chart with their 
                                             -- sequential numbers) e.g. '2,5,6,7,8,11,18,19,20,23,26,31,37,39,49,52,53,81,83,92'
	@Show_WKT    bit           = 0,      -- Print WKT string? 1=yes/0=no  This may be useful if you want to embed the graphics into another procedure.
                                             -- Note that when @Skip_Colors is not NULL or blank, then the resulting WKT will include lines for skipped colors. 
                                             -- These lines will be all the same and generally shorter than WKT representing actual data series from the given SELECT.
	@Debug       int           = 0       -- Reserved for system maintenance
AS
SET NOCOUNT ON;

DECLARE @Min_X			 float, 
		@Max_X			 float, 
		@Min_Y			 float, 
		@Max_Y			 float,
		@Zero_Y			 float,
		@Y_Base_Use		 float,
		@X_Count		 int, 
		@Col_Half		 float, 
		@Scale			 varchar(20),
		@N				 int,
		@First			 bit,
		@Char			 char(1),
		@New_Char		 char(1),
		@Len			 int,
		@Series_#		 int,
		@Series_Legend	 varchar(100),
		@Series_Count	 int,
		@Pie_Segment	 float,
		@Legend_Scale_X	 float,
		@Legend_Scale_Y	 float,
		@Legend_Offset_X float,
		@Legend_Offset_Y float,
		@Step			 float,
		@Step_Str		 varchar(100),
		@Y_Legend		 varchar(100),
		@Y				 float,
		@G				 varchar(max),
		@Break			 int,
		@Color			 int,
		@Skip_Color_WKT  varchar(max),
		@X0              float,
		@Y0              float,
		@X1              float,
		@Y1              float;

SET @Legend = COALESCE( @Legend, CASE WHEN @Chart_Type = 'PAINT' THEN 0 ELSE 1 END );
SET @Y_Grid = COALESCE( @Y_Grid, CASE WHEN @Chart_Type = 'PAINT' THEN 0 ELSE 1 END );

CREATE TABLE #Data ( 
	OrderBy	int IDENTITY(1,1), 
	Legend	varchar(100) NULL, 
	X		float NULL, 
	Y		float NULL, 
	Y0		float NULL
);
CREATE TABLE #Legend ( 
	ID			int IDENTITY(1,1), 
	Legend		varchar(100) NOT NULL PRIMARY KEY CLUSTERED,
	Pie_Segment	float NULL
);
CREATE TABLE #Area ( 
	Legend	varchar(100) NOT NULL,
	N		int NOT NULL,
	X		float NOT NULL, 
	Y		float NOT NULL
);
CREATE TABLE #Pie ( 
	OrderBy	int IDENTITY(1,1), 
	Legend	varchar(100) NULL, 
	Y		float NULL
);

IF @Chart_Type = 'PIE' EXEC( 'insert #Pie ( Legend, Y ) ' + @SQL );
ELSE EXEC( 'insert #Data ( Legend, X, Y ) ' + @SQL );

IF @Debug = 1 SELECT Debug = '#Data', * FROM #Data;

INSERT	#Legend ( Legend )
SELECT	Legend = COALESCE( Legend, '' )
FROM	#Data
GROUP BY Legend
ORDER BY MIN( OrderBy );

SELECT	@Series_Count = @@ROWCOUNT;

IF @Debug = 1 SELECT Debug = '#Legend', * FROM #Legend;

IF @Chart_Type = 'PIE' SELECT @Min_X = -1, @Max_X = 1;
ELSE SELECT	@Min_X   = MIN( X ), 
			@Max_X   = MAX( X + CASE WHEN @Chart_Type = 'BAR' THEN Y ELSE 0 END ),
			@X_Count = COUNT( DISTINCT X )
	 FROM	#Data;

IF @Chart_Type = 'AREA' BEGIN;
	INSERT	#Area ( Legend, N, X, Y )
	SELECT	Legend, ID, X, MAX( Y )
	FROM (	SELECT	l.Legend, 
					l.ID, 
					x.X, 
					Y = COALESCE( d.Y, ( 
								  SELECT  TOP 1 dd.Y 
								  FROM	  #Data dd 
								  WHERE   dd.Legend = l.Legend 
								  AND	  dd.X < x.X 
								  ORDER BY dd.X DESC ), 
								  0 )
			FROM ( SELECT DISTINCT X FROM #Data ) x
			CROSS JOIN #Legend l
			LEFT JOIN  #Data d
				ON	d.X = x.X
				AND d.Legend = l.Legend
		 ) z
	GROUP BY Legend, ID, X;

	IF @Debug = 1 SELECT Debug = '#Area', * FROM #Area;

	TRUNCATE TABLE #Data;

	WITH Area1 ( N, Legend, X, Y, Part ) AS (
		SELECT	N, Legend, X, Y, Part = 1
		FROM	#Area 
		WHERE	N > 0
		UNION ALL
		SELECT	a.N, l.Legend, a.X, a.Y, Part = -1
		FROM	#Area a 
		JOIN	#Legend l ON a.N = l.ID - 1
	)
	INSERT	#Data ( Legend, X, Y )
	SELECT	a.Legend, a.X, Y = SUM( B.Y )
	FROM	Area1 a
	JOIN	Area1 b ON b.N <= a.N AND b.X = a.X
	WHERE	b.Part = 1
	GROUP BY a.Legend, a.X, a.Part
	ORDER BY a.Legend, a.Part DESC, a.Part * a.X;

	INSERT	#Data ( Legend, X, Y )
	SELECT	Legend, CASE WHEN N = 0 THEN X0 ELSE X1 END, 0
	FROM	   ( SELECT TOP 1 Legend FROM #Legend ORDER BY ID ) l
	CROSS JOIN ( SELECT X0 = MIN( X ), X1 = MAX( X ) FROM #Area ) x
	CROSS JOIN ( SELECT N = 0 UNION ALL SELECT N = 1 ) n
	ORDER BY N DESC;

	IF @Debug = 1 SELECT Debug = '#Data', * FROM #Data;
END;
ELSE IF @Chart_Type = 'COLUMN' BEGIN;
	UPDATE	d1
	SET		Y0 = (	SELECT	SUM( Y )
					FROM	#Data d0
					JOIN	#Legend l0 ON l0.Legend = d0.Legend
					WHERE	l0.ID < l1.ID
					AND		d0.X = d1.X
				 )
	FROM	#Data d1
	JOIN	#Legend l1 ON l1.Legend = d1.Legend
	WHERE	l1.ID > 1;

	IF @Debug = 1 SELECT Debug = '#Data', * FROM #Data;
END;
ELSE IF @Chart_Type = 'PIE' BEGIN;
	DECLARE @Sum float, @All_Other_Sum float, @All_Other_Count int;

	SELECT	@Sum = SUM( Y ) FROM #Pie;

	SELECT	@All_Other_Sum = SUM( Y ), 
			@All_Other_Count = COUNT(*) 
	FROM	#Pie 
	WHERE	Y / @Sum < @All_Other;

	IF @All_Other_Count > 1 BEGIN;
		DELETE #Pie WHERE Y / @Sum < @All_Other;
		INSERT #Pie ( Legend, Y ) VALUES ( 'All Other', @All_Other_Sum );
	END;

	UPDATE #Pie SET Y = @Sum / 1000. WHERE Y < @Sum / 1000.;

	IF @Debug = 1 SELECT [#Pie] = '#Pie', * FROM #Pie;

	IF @Debug > 0
			SELECT	a.Legend,
					a.OrderBy,
					Y1 = ROUND( COALESCE( SUM( b.Y / @Sum * 1000. ), 0 ), 0 ),
					Y2 = ROUND( ( COALESCE( SUM( b.Y ), 0 ) + a.Y ) / @Sum * 1000., 0 )
			FROM	#Pie a
			LEFT JOIN #Pie a ON b.OrderBy < a.OrderBy
			GROUP BY a.Legend, a.OrderBy, a.Y;

	INSERT	#Data ( Legend, X, Y )
	SELECT	r.Legend, 
			CASE WHEN n.N IN ( -1, 1001 ) THEN 0 ELSE n.X END,
			CASE WHEN n.N IN ( -1, 1001 ) THEN 0 ELSE n.Y END
	FROM (	SELECT	a.Legend,
					a.OrderBy,
					Y1 = ROUND( COALESCE( SUM( b.Y / @Sum * 1000. ), 0 ), 0 ),
					Y2 = ROUND( ( COALESCE( SUM( b.Y ), 0 ) + a.Y ) / @Sum * 1000., 0 )
			FROM	#Pie a
			LEFT JOIN #Pie b ON b.OrderBy < a.OrderBy
			GROUP BY a.Legend, a.OrderBy, a.Y
		 ) r
	JOIN (	SELECT	TOP 1003 N, X = SIN( N * PI() * .002 ), Y = COS( N * PI() * .002 )
			FROM (	SELECT	N = A + B + C + D + E + F + G + H + I + J - 1
					FROM	   ( SELECT A = 0 UNION ALL SELECT A =   1 ) a
					CROSS JOIN ( SELECT B = 0 UNION ALL SELECT B =   2 ) b
					CROSS JOIN ( SELECT C = 0 UNION ALL SELECT C =   4 ) c
					CROSS JOIN ( SELECT D = 0 UNION ALL SELECT D =   8 ) d
					CROSS JOIN ( SELECT E = 0 UNION ALL SELECT E =  16 ) e
					CROSS JOIN ( SELECT F = 0 UNION ALL SELECT F =  32 ) f
					CROSS JOIN ( SELECT G = 0 UNION ALL SELECT G =  64 ) g
					CROSS JOIN ( SELECT H = 0 UNION ALL SELECT H = 128 ) h
					CROSS JOIN ( SELECT I = 0 UNION ALL SELECT I = 256 ) i
					CROSS JOIN ( SELECT J = 0 UNION ALL SELECT J = 512 ) j
				 ) N
			ORDER BY N
		 ) n ON ( r.Y1 >= 1000 AND n.N BETWEEN 999  AND 1000     ) -- handle too-thin slices
			 OR ( r.Y1  = r.Y2 AND n.N BETWEEN r.Y1 AND r.Y1 + 1 ) -- handle too-thin slices
			 OR n.N BETWEEN r.Y1 and r.Y2
			 OR n.N IN ( -1, 1001 ) -- start and end at the center
	ORDER BY n.N, r.OrderBy;

	IF @Debug = 1 SELECT Debug = '#Data', * FROM #Data;

	SET @Y_Scale = 1;

	INSERT	#Legend ( Legend, Pie_Segment ) 
	SELECT	a.Legend,
			Pie_Segment = PI() * ( 2.5 - ( COALESCE( SUM( b.Y ), 0 ) + a.Y * .5 ) / @Sum * 2. )
	FROM	#Pie a
	LEFT JOIN #Pie b ON b.OrderBy < a.OrderBy
	GROUP BY a.Legend, a.OrderBy, a.Y
	ORDER BY a.OrderBy;
END;

SELECT	@Y_Base_Use = CASE WHEN COALESCE( @Y_Base, Min_Y ) >= Max_Y THEN Max_Y - ( Max_Y - Min_Y ) * .01 ELSE COALESCE( @Y_Base, Min_Y ) END
FROM	( SELECT Min_Y = MIN( CASE WHEN Y0 < Y THEN Y0 ELSE Y END ), Max_Y = MAX( Y ) FROM #Data ) d;

IF @Y_Base_Use > 0 AND @Y_Base IS NULL SET @Y_Base_Use = 0;

IF @Debug = 1 SELECT [@Y_Base_Use] = @Y_Base_Use;
IF @Debug = 1 SELECT [#Legend] = '#Legend', * FROM #Legend;

SELECT	@Min_Y = CASE WHEN @Chart_Type = 'BAR' THEN 0
					  WHEN @Chart_Type in ( 'COLUMN', 'AREA' ) THEN @Y_Base_Use
					  ELSE MIN( Y )
				 END, 
		@Max_Y = CASE WHEN @Chart_Type = 'BAR' THEN @Series_Count
					  WHEN @Chart_Type in ( 'COLUMN', 'AREA' ) THEN CASE WHEN MAX( COALESCE( Y0, 0 ) + Y ) < @Y_Base_Use THEN @Y_Base_Use ELSE MAX( COALESCE( Y0, 0 ) + Y ) END
					  ELSE MAX( Y )
				 END
FROM	#Data;

IF @Debug > 0 SELECT 'debug 1', [@Min_X] = @Min_X, [@Max_X] = @Max_X, [@Min_Y] = @Min_Y, [@Max_Y] = @Max_Y, [@X_Count] = @X_Count, [@Y_Scale] = @Y_Scale;

IF @Y_Scale IS NULL BEGIN;
	SET @Scale = CAST( ( @Max_Y - @Min_Y ) / 
				 CASE WHEN @Max_X - @Min_X = 0 
					  THEN 1 
					  ELSE @Max_X - @Min_X 
				 END * 4. AS varchar(30) );

	SELECT	@N     = 1, 
			@First = 1, 
			@Char  = LEFT( @Scale, 1 ), 
			@Len   = LEN( @Scale );

	WHILE @N <= @Len AND @Char <> 'e' BEGIN;
		IF @Char LIKE '[1-9]' BEGIN;
			SET @Scale = STUFF( @Scale, @N, 1, 
						CASE WHEN @First = 0 THEN '0' 
							 WHEN @Scaling25 = 0 THEN '1'
							 ELSE SUBSTRING( '122255555', CAST( @Char AS int ), 1 )
						END );
			SET @First = 0;
		END;
		SET @N = @N + 1;
		IF @N <= @Len SET @Char = SUBSTRING( @Scale, @N, 1 );
	END;

	SET @Y_Scale = CAST( @Scale AS float );
END;

IF @Chart_Type = 'COLUMN' BEGIN;
	DECLARE @Distinct_X TABLE ( 
		N int	NOT NULL IDENTITY(1,1) PRIMARY KEY CLUSTERED, 
		X float	NOT NULL 
	);
	
	INSERT	@Distinct_X ( X ) 
	SELECT	DISTINCT X 
	FROM	#Data 
	WHERE	X IS NOT NULL;
	
	SELECT	@Col_Half = MIN( b.X - a.X )
	FROM	@Distinct_X a
	JOIN	@Distinct_X b ON a.N = b.N - 1;

	IF @Debug > 0 SELECT * FROM @Distinct_X;
	
	SET @Col_Half = COALESCE( NULLIF( @Col_Half, 0 ), ( @Max_X - @Min_X + 1 ) / @X_Count ) * @Col_Width * 0.5;
END;

SET @Zero_Y = ( @Max_Y - @Min_Y ) * .0001;

SELECT 'Y scale:', @Y_Scale;

SELECT	@X0 = CASE @Chart_Type WHEN 'PIE' THEN -1 WHEN 'COLUMN' THEN @Min_X - @Col_Half ELSE @Min_X END,
		@X1 = CASE @Chart_Type WHEN 'PIE' THEN  1 WHEN 'COLUMN' THEN @Max_X + @Col_Half ELSE @Max_X END,
		@Y0 = CASE @Chart_Type WHEN 'PIE' THEN -1 ELSE @Min_Y / @Y_Scale END,
		@Y1 = CASE @Chart_Type WHEN 'PIE' THEN  1 ELSE @Max_Y / @Y_Scale END;

SET @Legend_Scale_X  = CASE WHEN @Chart_Type = 'BAR' AND ( @Max_Y - @Min_Y ) * .05 > .7 THEN .7 
							ELSE ( @Max_Y - @Min_Y ) * .05 
					   END / @Y_Scale;
SET @Legend_Scale_Y  = @Legend_Scale_X;
SET @Legend_Offset_X = CASE WHEN @Chart_Type = 'PIE' THEN @X1 * 1.05
							WHEN @Chart_Type = 'BAR' AND @Legend_Over = 1 THEN @X0 + ( @X1 - @X0 ) * .02
							ELSE @X1 + ( @X1 - @X0 ) * .05
					   END;
SET @Legend_Offset_Y = CASE @Chart_Type WHEN 'BAR' THEN -.5 * ( 1. / @Y_Scale + @Legend_Scale_Y )
										WHEN 'AREA' THEN @Y0 - 1.5 * @Legend_Scale_Y 
										ELSE @Y1 + @Legend_Scale_Y * .5 
					   END;

IF @Debug > 0 SELECT 'debug 2', [@Legend_Scale_X] = @Legend_Scale_X, [@Legend_Scale_Y] = @Legend_Scale_Y, [@Legend_Offset_X] = @Legend_Offset_X, [@Legend_Offset_Y] = @Legend_Offset_Y, [@X0] = @X0, [@X1] = @X1, [@Y0] = @Y0, [@Y1] = @Y1, [@Col_Half] = @Col_Half;

DECLARE Series_Cursor CURSOR
FOR SELECT	 ID, Legend, Pie_Segment - CASE WHEN Pie_Segment > 2 * PI() THEN 2 * PI() ELSE 0 END 
	FROM	 #Legend 
	ORDER BY ID;

OPEN Series_Cursor;

FETCH NEXT FROM Series_Cursor INTO @Series_#, @Series_Legend, @Pie_Segment;

CREATE TABLE #FinalChart ( G varchar(max) not null, ID int identity(1,1) primary key clustered );

SET @Color = 0;

SET @Skip_Color_WKT = CASE WHEN @Chart_Type = 'LINE' THEN 'LINESTRING(' ELSE 'POLYGON((' END + 
					  CAST( @X0 AS varchar(30) ) + ' ' + CAST( @Y0 AS varchar(30) ) + ', ' + 
					  CAST( @X0 AS varchar(30) ) + ' ' + CAST( @Y0 + ( @Y1 - @Y0 ) * .0001 AS varchar(30) ) + ', ' + 
					  CAST( @X0 + ( @X1 - @X0 ) * .000025 AS varchar(30) ) + ' ' + CAST( @Y0 AS varchar(30) ) + ', ' + 
					  CAST( @X0 AS varchar(30) ) + ' ' + CAST( @Y0 AS varchar(30) ) + 
					  CASE WHEN @Chart_Type = 'LINE' THEN ')' ELSE '))' END;

WHILE @@FETCH_STATUS = 0 BEGIN;
	SET @Color = @Color + 1;

	WHILE CHARINDEX( ',' + CAST( @Color AS varchar(30) ) + ',', ',' + @Skip_Colors + ',' ) > 0 BEGIN;
		SET @Color = @Color + 1;
		INSERT #FinalChart ( G ) VALUES( @Skip_Color_WKT );
	END;
	
	IF @Debug > 0 SELECT 'debug 3', [@Series_#] = @Series_#, [@Series_Legend] = @Series_Legend, [@Color] = @Color;

	SET @G = (
		SELECT	CASE @Chart_Type 
					 WHEN 'BAR' THEN
							',((' + 
							CAST( d.X AS varchar(30) ) + ' ' +
							CAST( ( l.ID - 0.9 ) / @Y_Scale AS varchar(30) ) + ',' +
							CAST( d.X AS varchar(30) ) + ' ' +
							CAST( ( l.ID - 0.1 ) / @Y_Scale AS varchar(30) ) + ',' +
							CAST( d.X + case when d.Y = 0 then @Zero_Y else d.Y end AS varchar(30) ) + ' ' + 
							CAST( ( l.ID - 0.1 ) / @Y_Scale AS varchar(30) ) + ',' +
							CAST( d.X + case when d.Y = 0 then @Zero_Y else d.Y end AS varchar(30) ) + ' ' + 
							CAST( ( l.ID - 0.9 ) / @Y_Scale AS varchar(30) ) + ',' +
							CAST( d.X AS varchar(30) ) + ' ' + 
							CAST( ( l.ID - 0.9 ) / @Y_Scale AS varchar(30) ) + '))'
					 WHEN 'COLUMN' THEN 
							',((' + 
							CAST( d.X + @Col_Half AS varchar(30) ) + ' ' +
							CAST( CASE WHEN COALESCE( d.Y0, 0 ) < @Y_Base_Use THEN @Y_Base_Use ELSE COALESCE( d.Y0, 0 ) END / @Y_Scale AS varchar(30) ) + ',' +
							CAST( d.X - @Col_Half AS varchar(30) ) + ' ' +
							CAST( CASE WHEN COALESCE( d.Y0, 0 ) < @Y_Base_Use THEN @Y_Base_Use ELSE COALESCE( d.Y0, 0 ) END / @Y_Scale AS varchar(30) ) + ',' +
							CAST( d.X - @Col_Half AS varchar(30) ) + ' ' +
							CAST( CASE WHEN COALESCE( d.Y0, 0 ) + d.Y <= @Y_Base_Use THEN @Y_Base_Use + @Zero_Y ELSE COALESCE( d.Y0, 0 ) + d.Y + @Zero_Y END / @Y_Scale AS varchar(30) ) + ',' +
							CAST( d.X + @Col_Half AS varchar(30) ) + ' ' +
							CAST( CASE WHEN COALESCE( d.Y0, 0 ) + d.Y <= @Y_Base_Use THEN @Y_Base_Use + @Zero_Y ELSE COALESCE( d.Y0, 0 ) + d.Y + @Zero_Y END / @Y_Scale AS varchar(30) ) + ',' +
							CAST( d.X + @Col_Half AS varchar(30) ) + ' ' +
							CAST( CASE WHEN COALESCE( d.Y0, 0 ) < @Y_Base_Use THEN @Y_Base_Use ELSE COALESCE( d.Y0, 0 ) END / @Y_Scale AS varchar(30) ) + '))'
					 ELSE ',' + 
							CAST( d.X AS varchar(30) ) + ' ' + 
							CAST( CASE WHEN @Chart_Type = 'AREA' AND d.Y <= @Y_Base_Use THEN @Y_Base_Use + @Zero_Y ELSE d.Y END / @Y_Scale AS varchar(30) )
				END
		FROM	  #Data d
		LEFT JOIN #Legend l ON l.Legend = COALESCE( d.Legend, '' )
		WHERE	  l.ID = @Series_#
		ORDER BY  d.OrderBy
		FOR XML PATH('') );

	IF @Chart_Type IN ( 'COLUMN', 'BAR' ) 
		SET @G = STUFF( @G, 1, 1, 'MULTIPOLYGON(' ) + ')';
	ELSE IF @Chart_Type IN ( 'AREA', 'PIE', 'PAINT' )
		SET @G = 'MULTIPOLYGON(((' + STUFF( @G, 1, 1, '' ) + LEFT( @G, CHARINDEX( ',', @G, 2 ) - 1 ) + ')))';
	ELSE /*IF @Chart_Type = 'LINE'*/ 
		SET @G = STUFF( @G, 1, 1, 'MULTILINESTRING((' ) + '))';

	SET @Legend_Offset_Y = @Legend_Offset_Y + 
							CASE WHEN @Chart_Type = 'BAR' THEN 1. / @Y_Scale 
								 WHEN @Chart_Type = 'AREA' THEN 1.5 * @Legend_Scale_Y 
								 ELSE -1.5 * @Legend_Scale_Y
							END;

	IF @Chart_Type = 'PIE' AND @Legend_Over = 1 
		SELECT	@Legend_Offset_Y = 1.05 * SIN( @Pie_Segment ) - CASE WHEN @Pie_Segment > PI() THEN @Legend_Scale_Y ELSE 0 END,
				@Legend_Offset_X = 1.05 * COS( @Pie_Segment ) - CASE WHEN @Pie_Segment BETWEEN PI() * .5 and PI() * 1.5 THEN @Legend_Scale_X * .571 * ( 2 + LEN( @Series_Legend ) ) ELSE 0 END;
	
	IF @Debug > 0 SELECT 'debug 4', [@G] = @G, [@Legend_Offset_X] = @Legend_Offset_X, [@Legend_Offset_Y] = @Legend_Offset_Y, [@Pie_Segment] = @Pie_Segment, [@Legend] = @Legend, [Add Legend] = case when @G LIKE 'MULTIPOLYGON%' then 'yes' else 'no' end, [Legend WKT] = dbo.WKT_String( @Series_Legend, @Legend_Scale_X, @Legend_Offset_X, @Legend_Scale_Y, @Legend_Offset_Y );

	INSERT #FinalChart ( G )
	VALUES( CASE WHEN @Legend = 0 /*OR @G NOT LIKE 'MULTIPOLYGON%'*/ THEN @G
				 ELSE STUFF( @G, case when @Chart_Type = 'LINE' then 17 else 15 end, 0, 
							 dbo.WKT_String( CASE WHEN @Chart_Type = 'BAR' THEN @Series_Legend
												  WHEN @Chart_Type = 'PIE' AND @Legend_Over = 1 AND @Pie_Segment BETWEEN PI() * .5 and PI() * 1.5 THEN @Series_Legend + ' ' + CHAR(8)
												  ELSE CHAR(8) + ' ' + @Series_Legend
											 END, 
											 @Legend_Scale_X, @Legend_Offset_X, @Legend_Scale_Y, @Legend_Offset_Y ) + ',' )
			END
		  );

	FETCH NEXT FROM Series_Cursor INTO @Series_#, @Series_Legend, @Pie_Segment;
END;

CLOSE Series_Cursor;
DEALLOCATE Series_Cursor;

SET @G = NULL;

-- Add Y grid axis values:
IF @Chart_Type IN ( 'LINE', 'AREA', 'COLUMN', 'PAINT' ) AND @Y_Grid = 1 BEGIN;
	SET @Step_Str = CAST( ( @Max_Y - @Min_Y ) / 8. AS varchar(30) );
	SET @N = 0;
	SET @First = 1;
	SET @Len = LEN( @Step_Str );

	IF @Debug > 0 SELECT 'debug 5', [@N] = @N, [@Len] = @Len, [@Step_Str] = @Step_Str;

	WHILE @N < @Len BEGIN;
		SET @N = @N + 1;
		SET @Char = SUBSTRING( @Step_Str, @N, 1 );
		IF @Char = 'e' BREAK;
		IF @Char LIKE '[1-9]' BEGIN;
			IF @FIRST = 1 BEGIN;
				SET @New_Char = SUBSTRING( '1255500000', CAST( @Char AS INT ) + 
								CASE WHEN SUBSTRING( @Step_Str + '0',  @N + 1, 1 ) LIKE '[1-9]' 
									   OR SUBSTRING( @Step_Str + '00', @N + 1, 2 ) LIKE '.[1-9]' 
									 THEN 1 ELSE 0 
								END, 1 );
				SET @Step_Str = STUFF( @Step_Str, @N, 1, REPLACE( @New_Char, '0', '1' ) );
				SET @First = 0;
			END;
			ELSE SET @Step_Str = STUFF( @Step_Str, @N, 1, '0' );
		END;
	END;

	SET @Step = CAST( @Step_Str AS FLOAT ) * CASE WHEN @New_Char = '0' THEN 10 ELSE 1 END;
	SET @Legend_Offset_X = @Min_X - CASE WHEN @Chart_Type = 'COLUMN' THEN @Col_Half ELSE 0 END;
	SET @Y = FLOOR( @Min_Y / @Step ) * @Step;

	WHILE @Y <= @Max_Y + @Step * .5 BEGIN;
		SET @Y_Legend = REPLACE( REPLACE( REPLACE( REPLACE( CAST( @Y AS varchar(30) ), 
						'E+0', 'E+' ), 'E+0', 'E+' ), 'E-0', 'E-' ), 'E-0', 'E-' ) + ' -';
		SET @G = COALESCE( @G + ',', 'MULTIPOLYGON((' ) + 
				 dbo.WKT_String( @Y_Legend, 
								 @Legend_Scale_Y, 
								 @Legend_Offset_X - LEN( @Y_Legend ) * @Legend_Scale_Y * .571, 
								 @Legend_Scale_Y, 
								 CAST( @Y / @Y_Scale AS float ) - @Legend_Scale_Y * .5 );
		SET @Y = @Y + @Step;
	END;
END;

-- Print chart title:
SET @Title = RTRIM( LTRIM( @Title ) );

IF @Debug > 0 SELECT '@Title=', '"' + @Title + '"';

IF COALESCE( @Title, '' ) <> '' BEGIN;
	IF LEN( @Title ) > 55 BEGIN;
		SET @Break = CHARINDEX( ' ', @Title, LEN( @Title ) / 2 );

		IF @Break > 0 BEGIN;
			IF @Debug > 0 SELECT 'debug 6', [@Title] = @Title, [@Break] = @Break, [@text] = LEFT( @Title, @Break - 1 ), [@xs] = @Legend_Scale_Y * 1.5, [@xo] = ( @Min_X + @Max_X + CASE WHEN @Chart_Type = 'COLUMN' THEN 1 ELSE 0 END - @Legend_Scale_Y * .8565 * ( @Break - 1 ) ) * .5, [@ys] = @Legend_Scale_Y * 1.5, [@yo] = @Max_Y + ( @Max_Y - @Min_Y ) * .1 + @Legend_Scale_Y * 2.25;

			SET @G = COALESCE( @G + ',', 'MULTIPOLYGON((' ) + 
					 dbo.WKT_String( RTRIM( LEFT( @Title, @Break - 1 ) ), 
									 @Legend_Scale_Y * 1.5, 
									 ( @X0 + @X1 - @Legend_Scale_Y * .8565 * LEN( RTRIM( LEFT( @Title, @Break - 1 ) ) ) ) * .5, 
									 @Legend_Scale_Y * 1.5, 
									 ( @Y1 + ( @Y1 - @Y0 ) * .1 ) + @Legend_Scale_Y * 2.25 );

			SET @Title = LTRIM( STUFF( @Title, 1, @Break, '' ) );

			IF @Debug > 0 SELECT 'debug 7', [@Title] = @Title;
		END;
	END;

	IF @Debug > 0 SELECT 'debug 7', [@text] = @Title, [@xs] = @Legend_Scale_Y * 1.5, [@xo] = ( @X0 + @X1 - @Legend_Scale_Y * .8565 * LEN( @Title ) ) * .5, [@ys] = @Legend_Scale_Y * 1.5, [@yo] = ( @Y1 + ( @Y1 - @Y0 ) * .1 );
	
	SET @G = COALESCE( @G + ',', 'MULTIPOLYGON((' ) + 
			 dbo.WKT_String( @Title, 
							 @Legend_Scale_Y * 1.5, 
							 ( @X0 + @X1 - @Legend_Scale_Y * .8565 * LEN( @Title ) ) * .5, 
							 @Legend_Scale_Y * 1.5, 
							 ( @Y1 + ( @Y1 - @Y0 ) * .1 ) );
END;

IF @Debug > 0 SELECT 'debug 9', [@G] = @G;

IF @G IS NOT NULL BEGIN;
	SET @G = @G + '))';
	INSERT #FinalChart ( G ) VALUES( @G );
	IF @Show_WKT = 1 PRINT @G;
END;

IF @Show_WKT = 1 SELECT * FROM #FinalChart;

SELECT geometry::STGeomFromText( G, 0 ) FROM #FinalChart;
go

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
IF OBJECT_ID( 'dbo.Chart_Colors' ) IS NULL EXEC( 'CREATE PROC dbo.Chart_Colors AS SELECT x=0' )
GO
ALTER PROC dbo.Chart_Colors
----------------------------------------------------------------
-- Description: Display a color chart with color numbers
-- Revision History:
-- ---Date--- ---Programmer---- ---Description------------------
-- 2011-12-24 Andrew Zanevsky	Original public version.
----------------------------------------------------------------
	@Max_Number smallint = 256 -- how many colors to display; values higher than 1024 will most likely cause errors
AS
DECLARE @Scale int;
SET @Scale = SQRT( @Max_Number );

SELECT	geometry::STGeomFromText( 'MULTIPOLYGON((' + 
		dbo.WKT_String( CHAR(8) + ' ' + CAST( N AS varchar(30) ), 1, 
		( N - 1 ) % @Scale * 4, 1, @Scale - ( N - 1 ) / @Scale ) + '))', 0 )
FROM (	SELECT	TOP ( @Max_Number ) N = ROW_NUMBER() OVER( ORDER BY a.system_type_id )
		FROM       sys.types a
		CROSS JOIN sys.types b
	 ) x;
GO

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
IF OBJECT_ID( 'dbo.Chart_Free_Disk_Space' ) IS NULL EXEC( 'CREATE PROC dbo.Chart_Free_Disk_Space AS SELECT x=0' )
GO
ALTER PROC dbo.Chart_Free_Disk_Space
--------------------------------------------------------------------------------
-- Description: Display a pie chart of free disk space on local drives
-- Revision History:
-- ---Date--- ---Programmer---- ---Description----------------------------------
-- 2011-12-24 Katrin Zanevsky	Original public version.
--------------------------------------------------------------------------------
	@Skip_Colors varchar(1000) = '2,4,5,6,7,8,11,13,14,18,19,20,23,26,31,37,39,49,52,53,81,83,92' -- Comma-separated list of unwanted colors
AS
SET NOCOUNT ON;

DECLARE @Avg float, @Scale int, @Title varchar(100), @Length int;

CREATE TABLE #Free (
	Drive      char(20) NOT NULL,
	Space_MB   float   NOT NULL
);

INSERT #Free( Drive, Space_MB ) EXEC master.sys.xp_fixeddrives;

SELECT @Avg = MAX( Space_MB ) FROM #Free;

SET @Scale = CASE WHEN @Avg < 1024 THEN 1
				  WHEN @Avg < 1048576 THEN 1024
				  ELSE 1048576 
			 END;

SET @Title = 'Free disk space, ' + CASE WHEN @Avg < 1024 THEN 'MB'
										WHEN @Avg < 1048576 THEN 'GB'
										ELSE 'TB'
								   END;

SELECT @Length = MAX( LEN( LTRIM( STR( Space_MB / @Scale, 20, 1 ) ) ) ) FROM #Free;

UPDATE #Free SET Drive = RTRIM( Drive ) + ' - ' + STR( Space_MB / @Scale, @Length, 1 );

EXEC dbo.Chart @SQL = 'SELECT Drive, Space_MB FROM #Free', @Chart_Type = 'PIE', @Title = @Title, @Skip_Colors = @Skip_Colors;
GO

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
IF OBJECT_ID( 'dbo.Chart_DB_Size' ) IS NULL EXEC( 'CREATE PROC dbo.Chart_DB_Size AS SELECT x=0' )
GO
ALTER PROC dbo.Chart_DB_Size
--------------------------------------------------------------------------------
-- Description: Display a chart of database sizes
-- Revision History:
-- ---Date--- ---Programmer---- ---Description----------------------------------
-- 2011-12-24 Katrin Zanevsky	Original public version.
--------------------------------------------------------------------------------
    @Chart_Type  varchar(20)   = 'COLUMN',       -- Recommended types: COLUMN, PIE, or BAR
    @Title       varchar(100)  = null,		 -- Default: "Database size, GB" (or just "Database size" for PIE charts)
    @Skip_Colors varchar(1000) = '2,4,5,6,7,8,11,13,14,18,19,20,23,26,31,37,39,49,52,53,81,83,92' -- Comma-separated list of unwanted colors
AS
SET NOCOUNT ON;

DECLARE @SQL   varchar(8000),
        @Total float;

SET @Title = CASE @Chart_Type 
				  WHEN 'COLUMN' THEN 'Database size, GB'
				  WHEN 'BAR'    THEN 'Database size, GB'
				  WHEN 'PIE'    THEN 'Database size'
		     END;

CREATE TABLE #DB (
	Name                sysname       NOT NULL,
	DB_Size             nvarchar(13)  NOT NULL,
	Owner               sysname       NULL,
	DBID                smallint      NULL,
	Created             nvarchar(11)  NULL,
	Status              nvarchar(600) NULL,
	Compatibility_Level tinyint       NULL
);

INSERT #DB (
		Name,
		DB_Size,
		Owner,
		DBID,
		Created,
		Status,
		Compatibility_Level )
EXEC master.sys.sp_helpdb;

SELECT @Total = SUM( CAST( REPLACE( DB_Size, ' MB', '' ) AS float ) ) FROM #DB;

SET @SQL = CASE @Chart_Type 
				WHEN 'COLUMN' THEN 'SELECT D, X = ROW_NUMBER() OVER ( ORDER BY CASE WHEN D = ''All Other DBs'' THEN 1 ELSE 0 END, S DESC ), S'
				WHEN 'BAR'    THEN 'SELECT D, 0, S'
				WHEN 'PIE'    THEN 'SELECT D, S'
		   END + '
				FROM (	SELECT	D = CASE WHEN CAST ( REPLACE ( DB_Size, '' MB'', '''' ) AS float ) / ' + CAST ( @Total AS varchar(30) ) + ' < 0.05 THEN ''All Other DBs'' ELSE Name END,
								S = SUM ( CAST ( REPLACE ( DB_Size, '' MB'', '''' ) AS float ) ) / 1024.
						FROM	#DB
						GROUP BY CASE WHEN CAST ( REPLACE ( DB_Size, '' MB'', '''' ) AS float ) / ' + CAST ( @Total AS varchar(30) ) + ' < 0.05 THEN ''All Other DBs'' ELSE Name END 
					 ) x
				ORDER BY ' +
		   CASE @Chart_Type 
				WHEN 'COLUMN' THEN 'X'
				ELSE 'CASE WHEN D = ''All Other DBs'' THEN 1 ELSE 0 END, S DESC'
		   END;

EXEC dbo.Chart @SQL = @SQL, @Chart_Type = @Chart_Type, @Title = @Title, @Skip_Colors = @Skip_Colors;
GO

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
IF OBJECT_ID( 'dbo.Chart_Job_Duration' ) IS NULL EXEC( 'CREATE PROC dbo.Chart_Job_Duration AS SELECT x=0' )
GO
ALTER PROC dbo.Chart_Job_Duration
--------------------------------------------------------------------------------
-- Description: Display a line chart of execution history of a given job
-- Revision History:
-- ---Date--- ---Programmer---- ---Description----------------------------------
-- 2011-12-24 Katrin Zanevsky	Original public version.
--------------------------------------------------------------------------------
    @Job_Name   varchar(128),
    @Start_Date datetime = NULL, -- default = earliest available history of the given job
    @End_Date   datetime = NULL  -- default = now
AS
SET NOCOUNT ON;

DECLARE @SQL varchar(8000), @Title varchar(100), @Max int, @Scale int;

SET @Start_Date = COALESCE( @Start_Date, '1900-01-01' );
SET @End_Date   = COALESCE( @End_Date,   GETDATE() );

CREATE TABLE #Job_History (
    Run_Time         datetime     NOT NULL,
    Run_Duration_Sec int          NOT NULL
);

INSERT	#Job_History( Run_Time, Run_Duration_Sec )
SELECT	Run_Time = CAST( STUFF( STUFF( STR( h.run_date, 8 ), 7, 0, '-' ), 5, 0, '-' ) + ' ' +
				   STUFF( STUFF( RIGHT( STR( 1000000 + h.Run_Time, 7 ), 6 ), 5, 0, ':' ), 3, 0, ':' ) AS datetime ),
		Run_Duration_Sec = h.run_duration % 100 + h.run_duration / 100 % 100 * 60. + h.run_duration / 10000 * 3600.
FROM	msdb.dbo.sysjobhistory h 
JOIN	msdb.dbo.sysjobs j ON h.job_id = j.job_id
WHERE	h.step_id = 0
AND		j.Name = @Job_Name
AND		CAST( STUFF( STUFF( STR( h.run_date, 8 ), 7, 0, '-' ), 5, 0, '-' ) + ' ' +
		STUFF( STUFF( RIGHT( STR( 1000000 + h.Run_Time, 7 ), 6 ), 5, 0, ':' ), 3, 0, ':' ) AS datetime ) BETWEEN @Start_Date AND @End_Date;

SELECT	@Max = MAX( Run_Duration_Sec ) FROM #Job_History;

SET @Scale = CASE WHEN @Max < 120 THEN 1 WHEN @Max < 7200 THEN 60 ELSE 3600 END;

SET @Title = 'Job "' + LEFT( @Job_Name, 43 ) + '" (Y=job duration ' + 
			 CASE @Scale WHEN 1 THEN 'seconds' WHEN 60 THEN 'minutes' ELSE 'hours' END + 
			 ', X=days before ' + CONVERT( char(10), @End_Date, 121 ) + ')';

SET @SQL = 'SELECT	'''',
					X = DATEDIFF( minute, ''' + CONVERT( char(23), GETDATE(), 121 ) + ''', Run_Time ) / 1440.,
					Y = Run_Duration_Sec / ' + CAST( @Scale AS varchar(30) ) + '.
			FROM	#Job_History 
			ORDER BY X';

EXEC dbo.Chart @SQL = @SQL, @Chart_Type = 'LINE', @Title = @Title, @Legend = 0;
GO

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
IF OBJECT_ID( 'dbo.Chart_Job_Step_Duration' ) IS NULL EXEC( 'CREATE PROC dbo.Chart_Job_Step_Duration AS SELECT x=0' )
GO
ALTER PROC dbo.Chart_Job_Step_Duration
--------------------------------------------------------------------------------
-- Description: Display an area chart of execution history of a given job by step
-- Revision History:
-- ---Date--- ---Programmer---- ---Description----------------------------------
-- 2011-11-08 Katrin Zanevsky	Original public version.
-- 2011-12-06 Andrew Zanevsky	Disregard old partially purged executions.
-- 2011-12-24 Andrew Zanevsky	Use standard functions.
--------------------------------------------------------------------------------
    @Job_Name    varchar(128),
    @Start_Date  datetime      = NULL,   -- default = earliest available history of the given job
    @End_Date    datetime      = NULL,   -- default = now
    @Chart_Type	 varchar(20)   = 'AREA', -- Recommended types: AREA or COLUMN
    @Skip_Colors varchar(1000) = '2,4,5,6,7,8,11,13,14,18,19,20,23,26,31,37,39,49,52,53,81,83,92' -- Comma-separated list of unwanted colors
AS
SET NOCOUNT ON;

DECLARE @SQL varchar(8000), @Title varchar(100), @Max int, @Scale int;

SET @Start_Date = COALESCE( @Start_Date, '1900-01-01' );
SET @End_Date   = COALESCE( @End_Date,   GETDATE() );

CREATE TABLE #Job_History (
    ID               int          NOT NULL IDENTITY(1,1) PRIMARY KEY CLUSTERED,
    Step_ID          varchar(128) NOT NULL,
    Step_Name        varchar(100) NOT NULL,
    Run_Time         datetime     NULL,
    Run_Duration_Sec int          NOT NULL
);

INSERT	#Job_History( Step_ID, Step_Name, Run_Time, Run_Duration_Sec )
SELECT	Step_ID   = h.step_id,
		Step_Name = 'Step' + STR( h.step_id, 3 ) + ' - ' + LEFT( h.step_name, 90 ),
		Run_Time  = CAST( STUFF( STUFF( STR( h.run_date, 8 ), 7, 0, '-' ), 5, 0, '-' ) + ' ' +
				    STUFF( STUFF( RIGHT( STR( 1000000 + h.Run_Time, 7 ), 6 ), 5, 0, ':' ), 3, 0, ':' ) AS datetime ),
		Run_Duration_Sec = h.run_duration % 100 + h.run_duration / 100 % 100 * 60. + h.run_duration / 10000 * 3600.
FROM	msdb.dbo.sysjobhistory h 
JOIN	msdb.dbo.sysjobs j ON h.job_id = j.job_id
WHERE	j.Name = @Job_Name
AND		CAST( STUFF( STUFF( STR( h.run_date, 8 ), 7, 0, '-' ), 5, 0, '-' ) + ' ' +
		STUFF( STUFF( RIGHT( STR( 1000000 + h.Run_Time, 7 ), 6 ), 5, 0, ':' ), 3, 0, ':' ) AS datetime ) BETWEEN @Start_Date AND @End_Date
ORDER BY Run_Time, Step_ID;

UPDATE	h
SET		Run_Time = ( SELECT	TOP 1 s.Run_Time
					 FROM	#Job_History s
					 WHERE	s.ID < h.ID
					 AND	s.Step_ID = 0
					 ORDER BY s.ID DESC
				   )
FROM	#Job_History h
WHERE	Step_ID > 0;

DELETE	#Job_History WHERE Run_Time IS NULL;

SELECT	@Max = MAX( Run_Duration_Sec ) FROM #Job_History;

SET @Scale = CASE WHEN @Max < 120 THEN 1 WHEN @Max < 7200 THEN 60 ELSE 3600 END;

SET @Title = 'Job "' + LEFT( @Job_Name, 43 ) + '" (Y=job duration ' + 
			 CASE @Scale WHEN 1 THEN 'seconds' WHEN 60 THEN 'minutes' ELSE 'hours' END + 
			 ', X=days before ' + CONVERT( char(10), @End_Date, 121 ) + ')';

SET @SQL = 'SELECT	Step_Name,
					X = DATEDIFF( minute, ''' + CONVERT( char(23), GETDATE(), 121 ) + ''', Run_Time ) / 1440.,
					Y = Run_Duration_Sec / ' + CAST( @Scale AS varchar(30) ) + '.
			FROM	#Job_History 
			WHERE	Step_ID > 0
			ORDER BY Step_Name, X';

EXEC dbo.Chart @SQL = @SQL, @Chart_Type = @Chart_Type, @Title = @Title, @Col_Width = .9, @Skip_Colors = @Skip_Colors;
GO


--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
IF OBJECT_ID( 'dbo.Chart_All_Jobs_History' ) IS NULL EXEC( 'CREATE PROC dbo.Chart_All_Jobs_History AS SELECT x=0' )
GO
ALTER PROC dbo.Chart_All_Jobs_History
--------------------------------------------------------------------------------
-- Description: Display a bar chart of execution history of all scheduled jobs
-- Revision History:
-- ---Date--- ---Programmer---- ---Description----------------------------------
-- 2011-12-24 Katrin Zanevsky	Original public version.
--------------------------------------------------------------------------------
    @Start_Date       datetime      = NULL, -- Default = 24 hours before now
    @End_Date         datetime      = NULL, -- Default = now
    @Min_Duration_Sec int           = 0,    -- Don't report executions shorter than this
    @Title            varchar(100)  = NULL,
    @Skip_Colors      varchar(1000) = '2,4,5,6,7,8,11,13,14,18,19,20,23,26,31,37,39,49,52,53,81,83,92' -- Comma-separated list of unwanted colors
AS
SET NOCOUNT ON;

SET @Start_Date = COALESCE( @Start_Date, DATEADD ( HOUR, -24, GETDATE() ) );
SET @End_Date   = COALESCE( @End_Date, GETDATE() );
SET @Title		= COALESCE( @Title, 'Scheduled Job History             (X = hours before ' + CONVERT( char(16), @End_Date, 121 ) + ')' );

DECLARE @SQL varchar(8000);

CREATE TABLE #Job_History (
    Name             varchar(128) NOT NULL,
    Run_Time         datetime     NOT NULL,
    Run_Duration_Sec int          NOT NULL
);

INSERT	#Job_History( Name, Run_Time, Run_Duration_Sec )
SELECT	Name, Run_Time, Run_Duration_Sec
FROM (	SELECT	Name = CAST( j.Name AS varchar(128) ),
				Run_Time = CAST( STUFF( STUFF( STR( h.run_date, 8 ), 7, 0, '-' ), 5, 0, '-' ) + ' ' +
						   STUFF( STUFF( RIGHT( STR( 1000000 + h.Run_Time, 7 ), 6 ), 5, 0, ':' ), 3, 0, ':' ) AS datetime ),
				Run_Duration_Sec = h.run_duration % 100 + h.run_duration / 100 % 100 * 60. + h.run_duration / 10000 * 3600.
		FROM	msdb.dbo.sysjobhistory h JOIN msdb.dbo.sysjobs j ON h.job_id = j.job_id
		WHERE	h.step_id = 0
	 ) x
WHERE	Run_Time BETWEEN @Start_Date AND @End_Date
AND		Run_Duration_Sec >= @Min_Duration_Sec;

SET @SQL = 'SELECT	Name,
					X = DATEDIFF( SECOND, ''' + CONVERT( char(23), GETDATE(), 121 ) + ''', Run_Time ) / 3600.,
					Y = Run_Duration_Sec / 3600.
			FROM	#Job_History 
			ORDER BY Name, X';

EXEC dbo.Chart @SQL = @SQL, @Chart_Type = 'BAR', @Title = @Title, @Skip_Colors = @Skip_Colors;
GO

--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
IF OBJECT_ID( 'dbo.Chart_Art' ) IS NULL EXEC( 'CREATE PROC dbo.Chart_Art AS SELECT x=0' )
GO
ALTER PROC Chart_Art
--------------------------------------------------------------------------------
-- Description: Generate a "random" drawing
-- Revision History:
-- ---Date--- ---Programmer---- ---Description----------------------------------
-- 2011-12-24 Andrew Zanevsky	Original public version.
--------------------------------------------------------------------------------
    @Seed  int	    = NULL, -- Use a specific integer seed to reproduce a
                            -- particular drawing or NULL for a random drawing.
    @Color smallint = NULL  -- Color number (execute Chart_Color for help) 
                            -- or NULL for a "random" color defined by @Seed.
AS
DECLARE @SQL varchar(8000), 
		@r1 float, @r2 float, @r3 float, @r4 float, @r5 varchar(3), 
		@Skip_Colors varchar(1000);
		
SET @Seed = COALESCE( @Seed, CAST( CAST( RIGHT( NEWID(), 4 ) AS binary(4) ) AS int ) );
SET @r1 = RAND( @Seed );
SET @r2 = CASE WHEN @Seed % 2 = 0 THEN @r1 ELSE RAND( @r1 * 2147483647 ) END;
SET @r3 = RAND( @r2 * 2147483647 );
SET @r4 = CASE WHEN @Seed % 4 < 2 THEN @r3 ELSE RAND( @r3 * 2147483647 ) END;
SET @r5 = CAST( POWER( 2, CAST( RAND( @r4 * 2147483647 ) * 6 AS int ) ) AS varchar(30) );
SET @Color = COALESCE( @Color, RAND( @r4 * 999999999 ) * 100. + 1 );
SET @Skip_Colors = '';

SELECT Seed = @Seed, Color = @Color;

WHILE @Color > 1 BEGIN;
	SET @Color = @Color - 1;
	SET @Skip_Colors = @Skip_Colors + ',' + CAST( @Color AS varchar(30) );
END;

SET @SQL = '
SELECT	Legend = '''', 
		x = SIN( PI() * n / 512. ) ' + CASE WHEN @r1 < 1./3. THEN '+' WHEN @r1 > 2./3. THEN '-' ELSE '*' END + ' SIN( PI() * n / ' + STR( @r3 * 500 + 1, 10, 0 ) + '. ) * ( n % ' + @r5 + ' / ' + @r5 + '. + 1 ) + SIN( PI() * n / 64. ) * .5,
		y = COS( PI() * n / 512. ) ' + CASE WHEN @r2 < 1./3. THEN '+' WHEN @r2 > 2./3. THEN '-' ELSE '*' END + ' COS( PI() * n / ' + STR( @r4 * 500 + 1, 10, 0 ) + '. ) * ( n % ' + @r5 + ' / ' + @r5 + '. + 1 ) + COS( PI() * n / 64. ) * .5
FROM (	SELECT TOP 1025 n = ROW_NUMBER() OVER ( ORDER BY a.system_type_id ) - 1
		FROM       sys.types a
		CROSS JOIN sys.types b
	 ) n
ORDER BY n';

EXEC dbo.Chart @SQL = @SQL, @Chart_Type = 'PAINT', @Y_Scale = 1, @Y_Grid = 0, @Legend = 0, @Skip_Colors = @Skip_Colors;
GO
